Learn R Programming

alphastable (version 0.2.1)

mfitstab.elliptical: mfitstab.elliptical

Description

estimates the parameters of a d-dimensional elliptically contoured stable distribution, see Teimouri et al. (2018).

Usage

mfitstab.elliptical(yy, alpha0, Sigma0, Mu0)

Arguments

yy

vector of d-dimensional realizations

alpha0

initial value of the tail index parameter to start the EM algorithm

Sigma0

initial value of the dispersion matrix to start the EM algorithm

Mu0

initial value of the location vector to start the EM algorithm

Value

alpha

estimated value of the tail index parameter

Sigma

estimated value of the dispersion matrix

Mu

estimated value of the location vector

References

Teimouri, M., Rezakhah, S., and Mohammadpour, A. (2018). Parameter estimation using the EM algorithm for symmetric stable random variables and sub-Gaussian random vectors, Journal of Statistical Theory and Applications, 17(3),1-20,

Examples

Run this code
# NOT RUN {
# Here we follow for applying the EM algorithm to Z=(x1, x2)^T using the
# initial values alpha0=1, Sigma0=matrix(c(0.75,0.25,0.25,0.75),2,2), and
# Mu0=(0.5,0.5)^T.
library("stabledist")
x1<-urstab(100,1.2,0,1,2,0)
x2<-urstab(100,1.2,0,0.5,2,0)
z<-cbind(x1,x2)
# }
# NOT RUN {
mfitstab.elliptical(z,1,matrix(c(0.75,0.25,0.25,0.75),2,2),c(0.5,0.5))
# }

Run the code above in your browser using DataLab