Learn R Programming

alphastable (version 0.2.1)

ufitstab.skew: ufitstab.skew

Description

using the EM algorithm, it estimates the parameters of skew stable distribution.

Usage

ufitstab.skew(y, alpha0, beta0, sigma0, mu0, param)

Arguments

y

vector of observations

alpha0

initial value of tail index parameter to start the EM algorithm

beta0

initial value of skewness parameter to start the EM algorithm

sigma0

initial value of scale parameter to start the EM algorithm

mu0

initial value of location parameter to start the EM algorithm

param

kind of parameterization; must be 0 or 1 for S_0 and S_1 parameterizations, respectively

Value

alpha

estimated value of the tail index parameter

beta

estimated value of the skewness parameter

sigma

estimated value of the scale parameter

mu

estimated value of the location parameter

Details

For any skew stable distribution we give a new representation by the following. Suppose Y~ S_{0}(alpha, beta, sigma, mu), P~ S_{1}(alpha/2,1,(cos(pi*alpha/4))^(2/alpha),0), and V~ S_{1}(alpha,1,1,0). Then, Y=eta*(2P)^(1/2)*N+theta*V+ mu-lambda, where eta=sigma*(1-|beta|)^(1/alpha), theta=sigma*sign(beta)*|beta|^(1/alpha), lambda=sigma*beta*tan(pi*alpha/2), and N~N(0,1) follows a skew stable distribution. All random variables N, P, and V are mutually independent.

References

Buckle, D. J. (1995). Bayesian inference for stable distributions, Journal of the American Statistical Association, 90(430), 605-613.

Examples

Run this code
# NOT RUN {
# For example, We use the daily price returns of Abbey National shares. Using the initial
# values as alpha_{0}=0.8, beta_{0}=0, sigma_{0}=0.25, and mu_{0}=0.25.
price<-c(296,296,300,302,300,304,303,299,293,294,294,293,295,287,288,297,
         305,307,304,303,304,304,309,309,309,307,306,304,300,296,301,298,
         295,295,293,292,307,297,294,293,306,303,301,303,308,305,302,301,
         297,299)
x<-c()
n<-length(price)
for(i in 2:n){x[i]<-(price[i-1]-price[i])/price[i-1]}
library("stabledist")
# }
# NOT RUN {
ufitstab.skew(x[2:n],0.8,0,0.25,0.25,1)
# }

Run the code above in your browser using DataLab